Learn R Programming

dataseries (version 1.0.0)

cache_ls: List or clear the in-memory cache

Description

Everything downloaded from dataseries.org is cached in memory for the lifetime of the R session. cache_ls() lists the cached objects (keyed by request URL); cache_rm() empties the cache, which forces the next call to download fresh data.

Usage

cache_ls()

cache_rm()

Arguments

Value

cache_ls() returns a character vector of cache keys; cache_rm()

is called for its side effect and returns NULL invisibly.

Examples

Run this code
if (FALSE) {
ds_catalog()
cache_ls()
cache_rm()
}

Run the code above in your browser using DataLab