Learn R Programming

dataseries (version 1.0.0)

ds_catalog: Catalog of available datasets

Description

Lists every dataset available on dataseries.org, one row per dataset. Use the id column with ds() to download data and with ds_meta() to inspect a dataset's dimensions.

Usage

ds_catalog()

Arguments

Value

A data.frame with one row per dataset and the columns id, title, concept, topic, source, license, frequency, start, end and n_series.

Examples

Run this code
if (FALSE) {
cat <- ds_catalog()
head(cat)

# search the catalog
cat[grepl("price", cat$title, ignore.case = TRUE), c("id", "title")]
}

Run the code above in your browser using DataLab